from langchain_openai import ChatOpenAI
import os
import getpass
import settings


def get_llm(llm_type="openai", temperature=0):
    if llm_type == "openai":
        os.environ["OPENAI_API_KEY"] = os.getenv("OPENAI_API_KEY") or getpass.getpass(
            "🔑 Enter your OPENAI API key: "
        )
        model = ChatOpenAI(
            model_name=settings.MODEL_NAME,
            temperature=temperature,
        )
        return model

    elif llm_type == "nvidia":
        model = ChatOpenAI(
            base_url=settings.MODEL_ENDPOINT,
            model_name=settings.MODEL_NAME,
            temperature=temperature,
            max_tokens=1024,
            top_p=1.0,
            # Nvidia NIM doesn't work if the API key is not set, even if we are using the local nim
            api_key=os.environ.get("NVIDIA_API_KEY", "APIKEY"),
        )
        return model

    else:
        raise ValueError(f"❌ Unsupported LLM type: {llm_type}")
