from neo4j import GraphDatabase
import pandas as pd
import settings


def execute_query(neo4j_query, transformer=None):
    URI = settings.NEO4J_URI
    AUTH = (settings.NEO4J_USER, settings.NEO4J_PASSWORD)

    with GraphDatabase.driver(URI, auth=AUTH) as driver:
        with driver.session(database=settings.NEO4J_DATABASE) as session:
            try:
                result = session.run(neo4j_query)

                # Check if the query is a procedure call (like graph creation)
                if neo4j_query.strip().upper().startswith("CALL"):
                    summary = result.consume()
                    return f"Procedure call completed successfully. {summary.counters}"

                # For regular queries, apply the transformer if provided
                if transformer:
                    return transformer(result)
                else:
                    # Default to returning a DataFrame
                    return pd.DataFrame([dict(record) for record in result])

            except Exception as e:
                print(f"An error occurred: {e}")
                return pd.DataFrame()
